@@ -68,6 +68,8 @@ clean_parameters.default <- function(x, group = "", ...) {
       "extra"
     } else if (grepl("scale", i, fixed = TRUE)) {
       "scale"
+    } else if (grepl("marginal", i, fixed = TRUE)) {
+      "marginal"
     } else {
       "conditional"
     }
@@ -272,6 +274,9 @@ clean_parameters.stanmvreg <- function(x, ...) {
 }
 
 
+#' @export
+clean_parameters.stanfit <- clean_parameters.stanreg
+
 
 #' @export
 clean_parameters.aovlist <- function(x, ...) {
