@@ -186,17 +186,23 @@
 
 # extract random effects from formula
 .get_model_random <- function(f, split_nested = FALSE, model) {
-  is_special <- inherits(model, c("MCMCglmm", "gee", "LORgee", "mixor", "clmm2", "felm", "feis", "bife", "BFBayesFactor", "BBmm", "glimML", "MANOVA", "RM", "cglm"))
-
-  if (!requireNamespace("lme4", quietly = TRUE)) {
-    stop("To use this function, please install package 'lme4'.")
-  }
+  is_special <- inherits(
+    model,
+    c(
+      "MCMCglmm", "gee", "LORgee", "mixor", "clmm2", "felm", "feis", "bife",
+      "BFBayesFactor", "BBmm", "glimML", "MANOVA", "RM", "cglm"
+    )
+  )
 
   if (identical(.safe_deparse(f), "~0") ||
     identical(.safe_deparse(f), "~1")) {
     return(NULL)
   }
 
+  if (!requireNamespace("lme4", quietly = TRUE)) {
+    stop("To use this function, please install package 'lme4'.")
+  }
+
   re <- sapply(lme4::findbars(f), .safe_deparse)
 
   if (is_special && .is_empty_object(re)) {
@@ -279,12 +285,12 @@
 # to reduce redundant code, I extract this part which is used several
 # times accross this package
 .get_elements <- function(effects, component) {
-  elements <- c("conditional", "conditional2", "conditional3", "precision", "nonlinear", "random", "zero_inflated", "zero_inflated_random", "dispersion", "instruments", "interactions", "simplex", "smooth_terms", "sigma", "nu", "tau", "correlation", "slopes", "cluster", "extra", "scale")
+  elements <- c("conditional", "conditional2", "conditional3", "precision", "nonlinear", "random", "zero_inflated", "zero_inflated_random", "dispersion", "instruments", "interactions", "simplex", "smooth_terms", "sigma", "nu", "tau", "correlation", "slopes", "cluster", "extra", "scale", "marginal")
 
   elements <- switch(
     effects,
     all = elements,
-    fixed = elements[elements %in% c("conditional", "conditional2", "conditional3", "precision", "zero_inflated", "dispersion", "instruments", "interactions", "simplex", "smooth_terms", "correlation", "slopes", "sigma", "nonlinear", "cluster", "extra", "scale")],
+    fixed = elements[elements %in% c("conditional", "conditional2", "conditional3", "precision", "zero_inflated", "dispersion", "instruments", "interactions", "simplex", "smooth_terms", "correlation", "slopes", "sigma", "nonlinear", "cluster", "extra", "scale", "marginal")],
     random = elements[elements %in% c("random", "zero_inflated_random")]
   )
 
@@ -306,7 +312,8 @@
     slopes = elements[elements == "slopes"],
     extra = elements[elements == "extra"],
     scale = elements[elements == "scale"],
-    precision = elements[elements == "precision"]
+    precision = elements[elements == "precision"],
+    marginal = elements[elements == "marginal"]
   )
 
   elements
@@ -463,6 +470,9 @@
 
 
 .safe_deparse <- function(string) {
+  if (is.null(string)) {
+    return(NULL)
+  }
   paste0(sapply(deparse(string, width.cutoff = 500), .trim, simplify = TRUE), collapse = " ")
 }
 
@@ -566,8 +576,9 @@
     direction = "long"
   )
 
-  if (is.factor(dat[[values_to]]))
+  if (is.factor(dat[[values_to]])) {
     dat[[values_to]] <- as.character(dat[[values_to]])
+  }
 
   dat[, 1:(ncol(dat) - 1), drop = FALSE]
 }
