@@ -34,9 +34,12 @@ is_model <- function(x) {
       "bamlss.frame",
       "bayesmeta",
       "bayesx",
+      "bayesQR",
       "BBmm",
       "BBreg",
       "bcplm",
+      "betamfx",
+      "betaor",
       "betareg",
       "BFBayesFactor",
       "bglmerMod",
@@ -136,6 +139,8 @@ is_model <- function(x) {
       "lmodel2",
       "lmerMod",
       "lmerModLmerTest",
+      "logitmfx",
+      "logitor",
       "lqmm",
       "lrm",
       "manova",
@@ -164,6 +169,8 @@ is_model <- function(x) {
       "mvmeta",
       "mvr",
       "negbin",
+      "negbinmfx",
+      "negbinirr",
       "nlreg",
       "nlrq",
       "nls",
@@ -172,8 +179,11 @@ is_model <- function(x) {
       "orcutt",
       "plm",
       "plmm",
+      "poissonmfx",
+      "poissonirr",
       "polr",
       "psm",
+      "probitmfx",
       "rdrobust",
       "ridgelm",
       "rjags",
