@@ -1,4 +1,4 @@
-.make_family <- function(x, fitfam = "gaussian", zero.inf = FALSE, hurdle = FALSE, logit.link = FALSE, multi.var = FALSE, link.fun = "identity", ...) {
+.make_family <- function(x, fitfam = "gaussian", zero.inf = FALSE, hurdle = FALSE, logit.link = FALSE, multi.var = FALSE, link.fun = "identity", dispersion = FALSE, ...) {
   # create logical for family
   binom_fam <-
     fitfam %in% c("bernoulli", "binomial", "quasibinomial", "binomialff") |
@@ -19,7 +19,7 @@
       fitfam %in% c("ztnbinom", "nbinom")
 
   beta_fam <-
-    inherits(x, "betareg") |
+    inherits(x, c("betareg", "betamfx")) |
       fitfam %in% c(
         "beta",
         "Beta",
@@ -58,7 +58,7 @@
     grepl("^hu", fitfam, perl = TRUE) |
     grepl("^truncated", fitfam, perl = TRUE) |
     fitfam == "ztnbinom" |
-    fitfam %in% c("truncpoiss", "truncnbinom", "truncnbinom1")
+    fitfam %in% c("truncpoiss", "truncnbinom", "truncnbinom1", "truncpoisson")
 
   is.ordinal <-
     inherits(x, c("svyolr", "polr", "clm", "clm2", "clmm", "mixor", "LORgee")) |
@@ -73,7 +73,7 @@
   is.bayes <- inherits(x, c(
     "brmsfit", "stanfit", "MCMCglmm", "stanreg",
     "stanmvreg", "bmerMod", "BFBayesFactor", "bamlss",
-    "bayesx", "mcmc", "bcplm"
+    "bayesx", "mcmc", "bcplm", "bayesQR"
   ))
 
   is.survival <- inherits(x, c("aareg", "survreg", "survfit", "survPresmooth", "flexsurvreg", "coxph", "coxme"))
@@ -186,6 +186,7 @@
     is_tweedie = tweedie_model,
     is_zeroinf = zero.inf,
     is_zero_inflated = zero.inf,
+    is_dispersion = dispersion,
     is_hurdle = hurdle,
     is_ordinal = is.ordinal,
     is_cumulative = is.ordinal,
