@@ -113,7 +113,7 @@ if (require("testthat") &&
     )
     expect_equal(nrow(get_parameters(m1)), 3)
     expect_equal(
-      get_parameters(m1)$parameter,
+      get_parameters(m1)$Parameter,
       c("(Intercept)", "log(rprice)", "log(rincome)")
     )
   })
@@ -133,7 +133,7 @@ if (require("testthat") &&
     )
     expect_equal(nrow(get_parameters(m1)), 3)
     expect_equal(
-      get_parameters(m1)$parameter,
+      get_parameters(m1)$Parameter,
       c("(Intercept)", "log(rprice)", "log(rincome)")
     )
   })
